@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2009 Fabrice Colin
+ *  Copyright 2005-2019 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,15 +16,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include <stdlib.h>
 #include <map>
 #include <set>
 #include <iostream>
 #include <cstring>
+#ifdef HAVE_BOOST_SPIRIT_CORE_HPP
 #include <boost/spirit/core.hpp>
 #include <boost/spirit/actor/push_back_actor.hpp>
 #include <boost/spirit/actor/insert_at_actor.hpp>
 #include <boost/spirit/utility/confix.hpp>
+#else
+#ifdef HAVE_BOOST_SPIRIT_INCLUDE_CLASSIC_HPP
+#define BOOST_SPIRIT_USE_OLD_NAMESPACE
+#include <boost/spirit/include/classic.hpp>
+#include <boost/spirit/home/classic/actor/push_back_actor.hpp>
+#include <boost/spirit/home/classic/actor/insert_at_actor.hpp>
+#include <boost/spirit/home/classic/utility/confix.hpp>
+#else
+#ifdef HAVE_BOOST_SPIRIT_HPP
+#include <boost/spirit.hpp>
+#include <boost/spirit/home/classic/actor/push_back_actor.hpp>
+#include <boost/spirit/home/classic/actor/insert_at_actor.hpp>
+#include <boost/spirit/home/classic/utility/confix.hpp>
+#endif
+#endif
+#endif
 
 #include "StringManip.h"
 #include "Url.h"
@@ -223,7 +241,7 @@ bool SherlockResponseParser::parse(const Document *pResponseDoc, vector<Document
 	unsigned int &totalResults, unsigned int &firstResultIndex, string &charset) const
 {
 	float pseudoScore = 100;
-	unsigned int contentLen = 0;
+	off_t contentLen = 0;
 	bool foundResult = false;
 
 	if ((pResponseDoc == NULL) ||
@@ -234,7 +252,8 @@ bool SherlockResponseParser::parse(const Document *pResponseDoc, vector<Document
 	}
 
 	// Can we get the charset ?
-	Dijon::HtmlFilter htmlFilter("text/html");
+	Dijon::HtmlFilter htmlFilter;
+	htmlFilter.set_mime_type("text/html");
 	if (FilterUtils::feedFilter(*pResponseDoc, &htmlFilter) == true)
 	{
 		const map<string, string> &metaData = htmlFilter.get_meta_data();
@@ -328,8 +347,9 @@ bool SherlockResponseParser::parse(const Document *pResponseDoc, vector<Document
 			chunkDoc.setData(dummyHtml.c_str(), dummyHtml.length());
 
 			// Feed this chunk to the filter
-			Dijon::HtmlFilter chunkFilter("text/html");
+			Dijon::HtmlFilter chunkFilter;
 			set<Dijon::Link> chunkLinks;
+			htmlFilter.set_mime_type("text/html");
 			if ((FilterUtils::feedFilter(chunkDoc, &chunkFilter) == true) &&
 				(chunkFilter.get_links(chunkLinks) == true) &&
 				(chunkFilter.next_document() == true))
@@ -455,7 +475,7 @@ ResponseParserInterface *SherlockParser::parse(SearchPluginProperties &propertie
 		return NULL;
 	}
 
-	unsigned int dataLength;
+	off_t dataLength;
 	const char *pData = pPluginDoc->getData(dataLength);
 	if ((pData == NULL) ||
 		(dataLength == 0))
