@@ -1,5 +1,5 @@
 /*
- *  Copyright 2005-2013 Fabrice Colin
+ *  Copyright 2005-2019 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -359,7 +359,7 @@ bool XapianIndex::listDocumentsWithTerm(const string &term, set<unsigned int> &d
 	}
 	catch (...)
 	{
-		clog << "Couldn't get document list, unknown exception occured" << endl;
+		clog << "Couldn't get document list, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -910,7 +910,7 @@ void XapianIndex::removeCommonTerms(Xapian::Document &doc, const Xapian::Writabl
 }
 
 string XapianIndex::scanDocument(const string &suggestedLanguage,
-	const char *pData, unsigned int dataLength)
+	const char *pData, off_t dataLength)
 {
 	vector<string> candidates;
 	string language;
@@ -924,7 +924,7 @@ string XapianIndex::scanDocument(const string &suggestedLanguage,
 	else
 	{
 		// Try to determine the document's language right away
-		LanguageDetector::getInstance().guessLanguage(pData, max(dataLength, (unsigned int)2048), candidates);
+		LanguageDetector::getInstance().guessLanguage(pData, max(dataLength, (off_t)2048), candidates);
 
 		scannedDocument = true;
 	}
@@ -951,7 +951,7 @@ string XapianIndex::scanDocument(const string &suggestedLanguage,
 			{
 				// The suggested language is not suitable
 				candidates.clear();
-				LanguageDetector::getInstance().guessLanguage(pData, max(dataLength, (unsigned int)2048), candidates);
+				LanguageDetector::getInstance().guessLanguage(pData, max(dataLength, (off_t)2048), candidates);
 
 				langIter = candidates.begin();
 				scannedDocument = true;
@@ -990,6 +990,8 @@ void XapianIndex::setDocumentData(const DocumentInfo &docInfo, Xapian::Document
 	doc.add_value(3, hhmmss);
 	// Date and time, for results sorting
 	doc.add_value(4, yyyymmdd + hhmmss);
+	// Number of seconds to January 1st, 10000
+	doc.add_value(5, Xapian::sortable_serialise((double )253402300800 - timeT));
 	// Any custom value ?
 	if (g_pMapper != NULL)
 	{
@@ -1046,7 +1048,7 @@ bool XapianIndex::deleteDocuments(const string &term)
 	}
 	catch (...)
 	{
-		clog << "Couldn't unindex documents, unknown exception occured" << endl;
+		clog << "Couldn't unindex documents, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1092,7 +1094,7 @@ string XapianIndex::getMetadata(const string &name) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't get metadata, unknown exception occured" << endl;
+		clog << "Couldn't get metadata, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1134,7 +1136,7 @@ bool XapianIndex::setMetadata(const string &name, const string &value) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't set metadata, unknown exception occured" << endl;
+		clog << "Couldn't set metadata, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1191,7 +1193,7 @@ bool XapianIndex::getDocumentInfo(unsigned int docId, DocumentInfo &docInfo) con
 	}
 	catch (...)
 	{
-		clog << "Couldn't get document properties, unknown exception occured" << endl;
+		clog << "Couldn't get document properties, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1229,7 +1231,7 @@ unsigned int XapianIndex::getDocumentTermsCount(unsigned int docId) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't get document terms count, unknown exception occured" << endl;
+		clog << "Couldn't get document terms count, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1314,7 +1316,7 @@ bool XapianIndex::getDocumentTerms(unsigned int docId, map<unsigned int, string>
 	}
 	catch (...)
 	{
-		clog << "Couldn't get document terms, unknown exception occured" << endl;
+		clog << "Couldn't get document terms, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1426,7 +1428,7 @@ bool XapianIndex::deleteLabel(const string &name)
 	}
 	catch (...)
 	{
-		clog << "Couldn't delete label, unknown exception occured" << endl;
+		clog << "Couldn't delete label, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1474,7 +1476,7 @@ bool XapianIndex::hasLabel(unsigned int docId, const string &name) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't check document labels, unknown exception occured" << endl;
+		clog << "Couldn't check document labels, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1526,7 +1528,7 @@ bool XapianIndex::getDocumentLabels(unsigned int docId, set<string> &labels) con
 	}
 	catch (...)
 	{
-		clog << "Couldn't get document's labels, unknown exception occured" << endl;
+		clog << "Couldn't get document's labels, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1603,7 +1605,7 @@ bool XapianIndex::setDocumentsLabels(const set<unsigned int> &docIds,
 		}
 		catch (...)
 		{
-			clog << "Couldn't update document's labels, unknown exception occured" << endl;
+			clog << "Couldn't update document's labels, unknown exception occurred" << endl;
 		}
 
 		pDatabase->unlock();
@@ -1651,7 +1653,7 @@ unsigned int XapianIndex::hasDocument(const string &url) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't look for document, unknown exception occured" << endl;
+		clog << "Couldn't look for document, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1713,7 +1715,7 @@ unsigned int XapianIndex::getCloseTerms(const string &term, set<string> &suggest
 	}
 	catch (...)
 	{
-		clog << "Couldn't get terms, unknown exception occured" << endl;
+		clog << "Couldn't get terms, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1746,7 +1748,7 @@ unsigned int XapianIndex::getLastDocumentID(void) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't get last document ID, unknown exception occured" << endl;
+		clog << "Couldn't get last document ID, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1791,7 +1793,7 @@ unsigned int XapianIndex::getDocumentsCount(const string &labelName) const
 	}
 	catch (...)
 	{
-		clog << "Couldn't count documents, unknown exception occured" << endl;
+		clog << "Couldn't count documents, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1845,7 +1847,7 @@ bool XapianIndex::indexDocument(const Document &document, const std::set<std::st
 	DocumentInfo docInfo(document);
 	docInfo.setLocation(Url::canonicalizeUrl(document.getLocation()));
 
-	unsigned int dataLength = 0;
+	off_t dataLength = 0;
 	const char *pData = document.getData(dataLength);
 
 	// Don't scan the document if a language is specified
@@ -1895,7 +1897,7 @@ bool XapianIndex::indexDocument(const Document &document, const std::set<std::st
 	}
 	catch (...)
 	{
-		clog << "Couldn't index document, unknown exception occured" << endl;
+		clog << "Couldn't index document, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -1918,7 +1920,7 @@ bool XapianIndex::updateDocument(unsigned int docId, const Document &document)
 	DocumentInfo docInfo(document);
 	docInfo.setLocation(Url::canonicalizeUrl(document.getLocation()));
 
-	unsigned int dataLength = 0;
+	off_t dataLength = 0;
 	const char *pData = document.getData(dataLength);
 
 	// Don't scan the document if a language is specified
@@ -1972,7 +1974,7 @@ bool XapianIndex::updateDocument(unsigned int docId, const Document &document)
 	}
 	catch (...)
 	{
-		clog << "Couldn't update document, unknown exception occured" << endl;
+		clog << "Couldn't update document, unknown exception occurred" << endl;
 	}
 	if (pIndex != NULL)
 	{
@@ -2023,7 +2025,7 @@ bool XapianIndex::updateDocumentInfo(unsigned int docId, const DocumentInfo &doc
 	}
 	catch (...)
 	{
-		clog << "Couldn't update document properties, unknown exception occured" << endl;
+		clog << "Couldn't update document properties, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -2063,7 +2065,7 @@ bool XapianIndex::unindexDocument(unsigned int docId)
 	}
 	catch (...)
 	{
-		clog << "Couldn't unindex document, unknown exception occured" << endl;
+		clog << "Couldn't unindex document, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
@@ -2123,7 +2125,11 @@ bool XapianIndex::flush(void)
 		Xapian::WritableDatabase *pIndex = pDatabase->writeLock();
 		if (pIndex != NULL)
 		{
+#if XAPIAN_NUM_VERSION >= 1001000
+			pIndex->commit();
+#else
 			pIndex->flush();
+#endif
 			flushed = true;
 		}
 	}
@@ -2133,7 +2139,7 @@ bool XapianIndex::flush(void)
 	}
 	catch (...)
 	{
-		clog << "Couldn't flush database, unknown exception occured" << endl;
+		clog << "Couldn't flush database, unknown exception occurred" << endl;
 	}
 	pDatabase->unlock();
 
