@@ -1,5 +1,5 @@
 /*
- *  Copyright 2011-2012 Fabrice Colin
+ *  Copyright 2011-2019 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
 #include <unistd.h>
 #include <stdarg.h>
 #include <stdlib.h>
@@ -25,7 +26,12 @@
 #include <exiv2/image.hpp>
 #include <exiv2/exif.hpp>
 #include <exiv2/iptc.hpp>
+#ifdef HAVE_EXIV2_XMP_EXIV2_HPP
+#include <exiv2/xmp_exiv2.hpp>
+#include <exiv2/error.hpp>
+#else
 #include <exiv2/xmp.hpp>
+#endif
 
 #include "config.h"
 #include "Exiv2ImageFilter.h"
@@ -37,29 +43,29 @@ using std::endl;
 using namespace Dijon;
 
 #ifdef _DYNAMIC_DIJON_FILTERS
-DIJON_FILTER_EXPORT bool get_filter_types(std::set<std::string> &mime_types)
+DIJON_FILTER_EXPORT bool get_filter_types(MIMETypes &mime_types)
 {
-	mime_types.clear();
+	mime_types.m_mimeTypes.clear();
 	// List from http://dev.exiv2.org/wiki/exiv2/Supported_image_formats
 	// without application/rdf+xml
-	mime_types.insert("image/jpeg");
-	mime_types.insert("image/x-exv");
-	mime_types.insert("image/x-canon-cr2");
-	mime_types.insert("image/x-canon-crw");
-	mime_types.insert("image/x-minolta-mrw");
-	mime_types.insert("image/tiff");
-	mime_types.insert("image/x-nikon-nef");
-	mime_types.insert("image/x-pentax-pef");
-	mime_types.insert("image/x-panasonic-rw2");
-	mime_types.insert("image/x-samsung-srw");
-	mime_types.insert("image/x-olympus-orf");
-	mime_types.insert("image/png");
-	mime_types.insert("image/pgf");
-	mime_types.insert("image/x-fuji-raf");
-	mime_types.insert("image/x-photoshop");
-	mime_types.insert("image/targa");
-	mime_types.insert("image/x-ms-bmp");
-	mime_types.insert("image/jp2");
+	mime_types.m_mimeTypes.insert("image/jpeg");
+	mime_types.m_mimeTypes.insert("image/x-exv");
+	mime_types.m_mimeTypes.insert("image/x-canon-cr2");
+	mime_types.m_mimeTypes.insert("image/x-canon-crw");
+	mime_types.m_mimeTypes.insert("image/x-minolta-mrw");
+	mime_types.m_mimeTypes.insert("image/tiff");
+	mime_types.m_mimeTypes.insert("image/x-nikon-nef");
+	mime_types.m_mimeTypes.insert("image/x-pentax-pef");
+	mime_types.m_mimeTypes.insert("image/x-panasonic-rw2");
+	mime_types.m_mimeTypes.insert("image/x-samsung-srw");
+	mime_types.m_mimeTypes.insert("image/x-olympus-orf");
+	mime_types.m_mimeTypes.insert("image/png");
+	mime_types.m_mimeTypes.insert("image/pgf");
+	mime_types.m_mimeTypes.insert("image/x-fuji-raf");
+	mime_types.m_mimeTypes.insert("image/x-photoshop");
+	mime_types.m_mimeTypes.insert("image/targa");
+	mime_types.m_mimeTypes.insert("image/x-ms-bmp");
+	mime_types.m_mimeTypes.insert("image/jp2");
 
 	return true;
 }
@@ -76,9 +82,9 @@ DIJON_FILTER_EXPORT bool check_filter_data_input(int data_input)
 	return false;
 }
 
-DIJON_FILTER_EXPORT Filter *get_filter(const std::string &mime_type)
+DIJON_FILTER_EXPORT Filter *get_filter(void)
 {
-	return new Exiv2ImageFilter(mime_type);
+	return new Exiv2ImageFilter();
 }
 #endif
 
@@ -153,8 +159,8 @@ static string exifDateTime(const string &value)
 	return "";
 }
 
-Exiv2ImageFilter::Exiv2ImageFilter(const string &mime_type) :
-	Filter(mime_type),
+Exiv2ImageFilter::Exiv2ImageFilter() :
+	Filter(),
 	m_parseDocument(false)
 {
 }
@@ -179,7 +185,7 @@ bool Exiv2ImageFilter::set_property(Properties prop_name, const string &prop_val
 	return false;
 }
 
-bool Exiv2ImageFilter::set_document_data(const char *data_ptr, unsigned int data_length)
+bool Exiv2ImageFilter::set_document_data(const char *data_ptr, off_t data_length)
 {
 	return false;
 }
