@@ -1,5 +1,5 @@
 /*
- *  Copyright 2011 Fabrice Colin
+ *  Copyright 2011-2016 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -27,7 +27,7 @@ namespace Dijon
     {
     public:
 	/// Builds an empty filter.
-	FileOutputFilter(const std::string &mime_type);
+	FileOutputFilter();
 	/// Destroys the filter.
 	virtual ~FileOutputFilter();
 
