@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007-2008 Fabrice Colin
+ *  Copyright 2007-2016 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 #include <set>
 #include <map>
 
+#include "HtmlParser.h"
 #include "Filter.h"
 
 namespace Dijon
@@ -50,19 +51,11 @@ namespace Dijon
     {
     public:
 	/// Builds an empty filter.
-	HtmlFilter(const std::string &mime_type);
+	HtmlFilter();
 	/// Destroys the filter.
 	virtual ~HtmlFilter();
 
 
-	/// initializes the 
-	static void initialize(void);
-
-	static void shutdown(void);
-
-
-	// Information.
-
 	/// Returns what data the filter requires as input.
 	virtual bool is_data_input_ok(DataInput input) const;
 
@@ -79,26 +72,26 @@ namespace Dijon
 	 * Filter object is destroyed, as some filters may not need to
 	 * do a deep copy of the data.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
-	virtual bool set_document_data(const char *data_ptr, unsigned int data_length);
+	virtual bool set_document_data(const char *data_ptr, off_t data_length);
 
 	/** (Re)initializes the filter with the given data.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_string(const std::string &data_str);
 
 	/** (Re)initializes the filter with the given file.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_file(const std::string &file_path,
 		bool unlink_when_done = false);
 
 	/** (Re)initializes the filter with the given URI.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_uri(const std::string &uri);
 
@@ -107,7 +100,7 @@ namespace Dijon
 
 	/** Returns true if there are nested documents left to extract.
 	 * Returns false if the end of the parent document was reached
-	 * or an error occured.
+	 * or an error occurred.
 	 */
 	virtual bool has_documents(void) const;
 
@@ -124,22 +117,27 @@ namespace Dijon
 
 	// Accessing documents' contents.
 
-	/// Returns the message for the most recent error that has occured.
+	/// Returns the message for the most recent error that has occurred.
 	virtual std::string get_error(void) const;
 
 	/// Returns the links set.
 	bool get_links(std::set<Link> &links) const;
 
-	class ParserState
+	class ParserState : public HtmlParser
 	{
 		public:
-			ParserState();
-			~ParserState();
+			ParserState(dstring &text);
+			virtual ~ParserState();
+
+			virtual void process_text(const string &text);
+			virtual void opening_tag(const string &tag);
+			virtual void closing_tag(const string &tag);
+
+			bool get_links_text(unsigned int currentLinkIndex);
 
 			bool m_isValid;
 			bool m_findAbstract;
 			unsigned int m_textPos;
-			std::string m_lastText;
 			bool m_inHead;
 			bool m_foundHead;
 			bool m_appendToTitle;
@@ -148,23 +146,28 @@ namespace Dijon
 			unsigned int m_skip;
 			std::string m_charset;
 			std::string m_title;
-			std::string m_text;
+			dstring &m_text;
 			std::string m_abstract;
 			Link m_currentLink;
 			std::set<Link> m_links;
 			std::set<Link> m_frames;
 			std::map<std::string, std::string> m_metaTags;
+
+		protected:
+			void append_whitespace(void);
+			void append_text(const string &text);
+
 	};
 
     protected:
-	ParserState *m_pState;
+	ParserState *m_pParserState;
 	std::string m_error;
 	bool m_skipText;
 	bool m_findAbstract;
 
 	virtual void rewind(void);
 
-	bool parse_html(const char *pData, unsigned int dataLen);
+	bool parse_html(const string &html);
 
     private:
 	/// HtmlFilter objects cannot be copied.
