@@ -1,5 +1,5 @@
 /*
- *  Copyright 2007 Fabrice Colin
+ *  Copyright 2007-2016 Fabrice Colin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ namespace Dijon
     {
     public:
 	/// Builds an empty filter.
-	XmlFilter(const std::string &mime_type);
+	XmlFilter();
 	/// Destroys the filter.
 	virtual ~XmlFilter();
 
@@ -52,26 +52,26 @@ namespace Dijon
 	 * Filter object is destroyed, as some filters may not need to
 	 * do a deep copy of the data.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
-	virtual bool set_document_data(const char *data_ptr, unsigned int data_length);
+	virtual bool set_document_data(const char *data_ptr, off_t data_length);
 
 	/** (Re)initializes the filter with the given data.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_string(const std::string &data_str);
 
 	/** (Re)initializes the filter with the given file.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_file(const std::string &file_path,
 		bool unlink_when_done = false);
 
 	/** (Re)initializes the filter with the given URI.
 	 * Call next_document() to position the filter onto the first document.
-	 * Returns false if this input is not supported or an error occured.
+	 * Returns false if this input is not supported or an error occurred.
 	 */
 	virtual bool set_document_uri(const std::string &uri);
 
@@ -80,7 +80,7 @@ namespace Dijon
 
 	/** Returns true if there are nested documents left to extract.
 	 * Returns false if the end of the parent document was reached
-	 * or an error occured.
+	 * or an error occurred.
 	 */
 	virtual bool has_documents(void) const;
 
@@ -97,7 +97,7 @@ namespace Dijon
 
 	// Accessing documents' contents.
 
-	/// Returns the message for the most recent error that has occured.
+	/// Returns the message for the most recent error that has occurred.
 	virtual std::string get_error(void) const;
 
     protected:
